Events class abstract

This class defines all the events that may be handled

You can listen to these events via:

kaleyraVideoPlugin.events.onCallModuleStatusChanged = (status) => {};

Properties

hashCode int
The hash code for this object.
no setterinherited
onCallError ↔ dynamic Function(String reason)?
Used to notify call errors
getter/setter pair
onCallModuleStatusChanged ↔ dynamic Function(String state)?
Used to notify call module status changed
getter/setter pair
onChatError ↔ dynamic Function(String reason)?
Used to notify chat errors
getter/setter pair
onChatModuleStatusChanged ↔ dynamic Function(String state)?
Used to notify chat module status changed
getter/setter pair
oniOSVoipPushTokenInvalidated ↔ dynamic Function()?
Used to notify voip push token invalidation
getter/setter pair
oniOSVoipPushTokenUpdated ↔ dynamic Function(String token)?
Used to notify voip push token updates
getter/setter pair
onSetupError ↔ dynamic Function(String reason)?
Used to notify setup errors
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited