Session class

Session

Constructors

Session(String userId, Future<String> accessTokenProvider(String))

Properties

accessTokenProvider Future<String> Function(String)
The accessTokenProvider
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
The user id you want to connect
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited