kaleyra_video_flutter_plugin library
Classes
- AudioCallOptions
- Audio call options used for chat
- CallKitConfiguration
- Configuration for callkit
- CallOptions
- Options available for a call
- ChatToolConfiguration
- Chat tool configuration
- Configuration
- Generic configuration for the Kaleyra Video plugin
- CreateCallOptions
- Options to be used when creating a call
- Environment
- Available environments
- Events
- This class defines all the events that may be handled
- IosConfiguration
- Configuration for iOS platform
- KaleyraVideo
- KaleyraVideo
- Region
- A region where your integration will run
- Screen Share tool configuration
- Session
- Session
- Tools
- Define the tools to use
- UserDetails
- This is used by Kaleyra Video to define the user details in the call/chat UI
Enums
- AudioCallType
- This class defines the types of audio calls supported.
- CallDisplayMode
- This class defines the display modes supported per call.
- CallType
- This class defines the types of calls supported.
- RecordingType
- Recording type of the call
- VoipHandlingStrategy
- This class defines the voip notification strategy per call.