KaleyraVideo class abstract
KaleyraVideo
Constructors
Properties
Methods
-
addUsersDetails(
List< UserDetails> userDetails) → dynamic - Call this method to provide the details for each user to be used to set up the UI
-
clearUserCache(
) → dynamic - This method allows you to clear all user cached data, such as chat messages and generic information.
-
connect(
Session session) → dynamic - Connect the plugin
-
disconnect(
) → dynamic - Stop the plugin
-
getCurrentVoIPPushToken(
) → Future< String?> - This method returns the current voip push token
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeUsersDetails(
) → dynamic - Call this method to remove all the user details previously provided.
-
setDisplayModeForCurrentCall(
CallDisplayMode mode) → dynamic - Set the UI display mode for the current call
-
startCall(
CreateCallOptions callOptions) → dynamic - Start Call with the callee defined
-
startCallFrom(
String url) → dynamic - Start Call from url
-
startChat(
String userID) → dynamic - Open chat
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
configure(
Configuration params) → Future< KaleyraVideo> - Call this method when device is ready to configure the module
-
reset(
) → dynamic - This method allows you to reset the configuration.